pub fn try_render_markdown(
content: &str,
options: &MarkdownOptions,
) -> Result<RenderResult>Expand description
Render markdown with explicit options, returning the full render result.
pub fn try_render_markdown(
content: &str,
options: &MarkdownOptions,
) -> Result<RenderResult>Render markdown with explicit options, returning the full render result.