SyntaxHighlighter

Struct SyntaxHighlighter 

pub struct SyntaxHighlighter { /* private fields */ }
Syntax highlighter for highlighting code

Implementations

Source

impl SyntaxHighlighter

pub fn new() -> Self

Create a new syntax highlighter

pub fn with_theme(theme: SyntaxTheme) -> Self

Create a new syntax highlighter with a specific theme

pub fn highlight(&self, code: &str, language: &str) -> Result<String>

Highlight code and return HTML

Errors

Returns Error::UnsupportedLanguage when the language name is not recognized or its lang-* feature is disabled.

pub fn highlight_with_lang( &self, code: &str, language: &Language, ) -> Result<String>

Highlight code with a known language

pub fn highlight_or_fallback(&self, code: &str, language: &str) -> String

Highlight code, falling back to a plain (escaped) <pre><code> block when the language is unknown or unsupported.

pub fn theme(&self) -> SyntaxTheme

Get the current theme

pub fn set_theme(&mut self, theme: SyntaxTheme)

Set the theme

pub fn is_language_supported(&self, language: &str) -> bool

Check if a language is supported

pub fn supported_languages(&self) -> Vec<&'static str>

Get list of supported languages

pub fn generate_stylesheet(&self) -> String

Generate CSS stylesheet for the current theme